==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/dbstubquery_test/loadcaltoservice_test.go <==
package dbstubquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbstubquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

func Test_LoadCalToService(t *testing.T) {
	testCases := []struct {
		Test               string
		MockGTFS           map[int]string
		Source             uint
		DateRange          [2]uint
		ExpectCalToService []dbt.CalToService
	}{
		{
			Test:      "Handles using calendar.txt in isolation",
			MockGTFS:  map[int]string{42: "../testhelper/mockgtfs/gtfs_cal_only.yml"},
			Source:    42,
			DateRange: [2]uint{20230620, 20230621},
			ExpectCalToService: []dbt.CalToService{
				// Source, ServiceDate, ServiceID
				{42, 20230620, "wk"},
				{42, 20230620, "wknd"},
				{42, 20230621, "wk"},
				{42, 20230621, "wknd"},
			},
		},
		{
			Test:               "Handles using calendar.txt in isolation (nop daterange)",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_cal_only.yml"},
			Source:             42,
			DateRange:          [2]uint{20270619, 20270622},
			ExpectCalToService: []dbt.CalToService{},
		},
		{
			Test:      "Handles using calendar_dates.txt in isolation",
			MockGTFS:  map[int]string{42: "../testhelper/mockgtfs/gtfs_caldates_only.yml"},
			Source:    42,
			DateRange: [2]uint{20230302, 20230303},
			ExpectCalToService: []dbt.CalToService{
				// Source, ServiceDate, ServiceID
				{42, 20230302, "bar"},
				{42, 20230303, "baz"},
				{42, 20230303, "bin"},
			},
		},
		{
			Test:               "Handles using calendar_dates.txt in isolation (nop daterange)",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_caldates_only.yml"},
			Source:             42,
			DateRange:          [2]uint{20230402, 20230703},
			ExpectCalToService: []dbt.CalToService{},
		},
		{
			Test:      "Handles using calendar.txt & calendar_dates.txt in combination",
			MockGTFS:  map[int]string{42: "../testhelper/mockgtfs/gtfs_cal_and_caldates.yml"},
			Source:    42,
			DateRange: [2]uint{20230906, 20230910},
			ExpectCalToService: []dbt.CalToService{
				// Source, ServiceDate, ServiceID
				{42, 20230906, "wk"},
				{42, 20230907, "wk"},
				{42, 20230907, "wknd"},
				{42, 20230909, "wk"},
				{42, 20230909, "wknd"},
				{42, 20230910, "special"},
				{42, 20230910, "wknd"},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if caltoservices, err := dbstubquery.LoadCalToService(
			sqlxDB, testCase.Source, testCase.DateRange[0], testCase.DateRange[1],
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(testCase.ExpectCalToService, *caltoservices) {
			t.Fatalf(
				"CalToService Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test, testCase.ExpectCalToService, *caltoservices, dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}

==> mobroute-0.7.0.tar.gz: mobroute-v0.7.0/dbstubquery_test/loadcaltoservice_test.go <==
package dbstubquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbstubquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

func Test_LoadCalToService(t *testing.T) {
	testCases := []struct {
		Test               string
		MockGTFS           map[int]string
		FeedID             uint
		DateRange          [2]uint
		ExpectCalToService []dbt.CalToService
	}{
		{
			Test:      "Handles using calendar.txt in isolation",
			MockGTFS:  map[int]string{42: "../testhelper/mockgtfs/gtfs_cal_only.yml"},
			FeedID:    42,
			DateRange: [2]uint{20230620, 20230621},
			ExpectCalToService: []dbt.CalToService{
				// FeedID, ServiceDate, ServiceID
				{42, 20230620, "wk"},
				{42, 20230620, "wknd"},
				{42, 20230621, "wk"},
				{42, 20230621, "wknd"},
			},
		},
		{
			Test:               "Handles using calendar.txt in isolation (nop daterange)",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_cal_only.yml"},
			FeedID:             42,
			DateRange:          [2]uint{20270619, 20270622},
			ExpectCalToService: []dbt.CalToService{},
		},
		{
			Test:      "Handles using calendar_dates.txt in isolation",
			MockGTFS:  map[int]string{42: "../testhelper/mockgtfs/gtfs_caldates_only.yml"},
			FeedID:    42,
			DateRange: [2]uint{20230302, 20230303},
			ExpectCalToService: []dbt.CalToService{
				// FeedID, ServiceDate, ServiceID
				{42, 20230302, "bar"},
				{42, 20230303, "baz"},
				{42, 20230303, "bin"},
			},
		},
		{
			Test:               "Handles using calendar_dates.txt in isolation (nop daterange)",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_caldates_only.yml"},
			FeedID:             42,
			DateRange:          [2]uint{20230402, 20230703},
			ExpectCalToService: []dbt.CalToService{},
		},
		{
			Test:      "Handles using calendar.txt & calendar_dates.txt in combination",
			MockGTFS:  map[int]string{42: "../testhelper/mockgtfs/gtfs_cal_and_caldates.yml"},
			FeedID:    42,
			DateRange: [2]uint{20230906, 20230910},
			ExpectCalToService: []dbt.CalToService{
				// FeedID, ServiceDate, ServiceID
				{42, 20230906, "wk"},
				{42, 20230907, "wk"},
				{42, 20230907, "wknd"},
				{42, 20230909, "wk"},
				{42, 20230909, "wknd"},
				{42, 20230910, "special"},
				{42, 20230910, "wknd"},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if caltoservices, err := dbstubquery.LoadCalToService(
			sqlxDB, testCase.FeedID, testCase.DateRange[0], testCase.DateRange[1],
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(testCase.ExpectCalToService, *caltoservices) {
			t.Fatalf(
				"CalToService Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test, testCase.ExpectCalToService, *caltoservices, dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}
